@@ -52,6 +52,8 @@ typedef struct _LogEntry
 } LogEntry;
 
 
+static void _ipatch_converter_free_converter_info(IpatchConverterInfo *data,
+                                                  gpointer user_data);
 static gint priority_GCompareFunc(gconstpointer a, gconstpointer b);
 static const IpatchConverterInfo *convert_lookup_map_U(GType **array, GType conv_type,
         GType src_type, GType dest_type, guint flags);
@@ -68,7 +70,31 @@ G_LOCK_DEFINE_STATIC(conv_maps);
 static GList *conv_maps = NULL;	/* list of all registered IpatchConverterInfo */
 static gpointer parent_class = NULL;
 
+/*------ Initialization/deinitialization of converter system ----------------*/
+/* Initialize converter system (conv_maps static list) */
+void _ipatch_converter_init(void)
+{
+    /* list of all registered IpatchConverterInfo */
+    conv_maps = NULL;
+}
 
+/* Free converter system */
+void _ipatch_converter_deinit(void)
+{
+    /* free list of all registered IpatchConverterInfo */
+    g_list_foreach(conv_maps,
+                   (GFunc)_ipatch_converter_free_converter_info, NULL);
+    g_list_free(conv_maps);
+}
+
+/* free one conv_maps data */
+static void _ipatch_converter_free_converter_info(IpatchConverterInfo *data,
+                                                  gpointer user_data)
+{
+    g_slice_free(IpatchConverterInfo,data);
+}
+
+/*------ Converter system API ----------------------------------------------*/
 /**
  * ipatch_convert_objects:
  * @input: Input object
@@ -216,6 +242,10 @@ ipatch_convert_object_to_type_multi(GObject *object, GType type, GError **err)
 GList *
 ipatch_convert_object_to_type_multi_list(GObject *object, GType type, GError **err)
 {
+    /* Note: empty is intentionally not initialized. It allows to fix some build on ARM and PPC.
+       It is save to use, because empty is not accessed in ipatch_convert_object_to_type_multi_set_vlist
+       when the second last argument is NULL.
+    */
     va_list empty;
     return (ipatch_convert_object_to_type_multi_set_vlist(object, type, err, NULL, empty));
 }
@@ -295,6 +325,7 @@ ipatch_convert_object_to_type_multi_set_vlist(GObject *object, GType type, GErro
         return NULL;
     }
 
+    /* assign properties (if any) */
     if(first_property_name)
     {
         g_object_set_valist((GObject *)conv, first_property_name, args);
