@@ -54,6 +54,7 @@ G_LOCK_DEFINE_STATIC(param_prop_hash);
 /* GParamSpec GValue property hash */
 static GHashTable *param_prop_hash = NULL;
 
+/* Initialization/deinitialization of GParamSpec extended properties system */
 
 /**
  * _ipatch_param_init: (skip)
@@ -90,6 +91,15 @@ _ipatch_param_init(void)
                        _("Type of units used"), 0, G_MAXUINT, 0, G_PARAM_READWRITE));
 }
 
+/* Freeing GParamSpec extended properties  system */
+void
+_ipatch_param_deinit(void)
+{
+	g_hash_table_destroy(param_prop_hash);
+}
+
+/* -- API of GParamSpec extended properties  system ---------------------*/
+
 /**
  * ipatch_param_install_property:
  * @prop_spec: Specification for the new #GParamSpec property.  Ownership
