@@ -132,7 +132,7 @@ ipatch_sf2_preset_class_init(IpatchSF2PresetClass *klass)
     IpatchItemClass *item_class = IPATCH_ITEM_CLASS(klass);
     IpatchContainerClass *container_class = IPATCH_CONTAINER_CLASS(klass);
 
-    parent_class = g_type_class_ref(IPATCH_TYPE_CONTAINER);
+    parent_class = g_type_class_peek_parent(klass);
 
     obj_class->finalize = ipatch_sf2_preset_finalize;
     obj_class->get_property = ipatch_sf2_preset_get_property;
