@@ -246,10 +246,10 @@ _dls2_sample_to_sf2_voice_cache_convert(IpatchConverter *converter,
     return (TRUE);
 }
 
-CONVERTER_CLASS_INIT(dls2_inst_to_sf2_voice_cache);
-CONVERTER_CLASS_INIT(dls2_region_to_sf2_voice_cache);
-CONVERTER_CLASS_INIT(dls2_sample_to_sf2_voice_cache);
+CONVERTER_CLASS_INIT(dls2_inst_to_sf2_voice_cache)
+CONVERTER_CLASS_INIT(dls2_region_to_sf2_voice_cache)
+CONVERTER_CLASS_INIT(dls2_sample_to_sf2_voice_cache)
 
-CONVERTER_SF2_VOICE_CACHE_GET_TYPE(dls2_inst_to_sf2_voice_cache, DLS2InstToSF2VoiceCache);
-CONVERTER_SF2_VOICE_CACHE_GET_TYPE(dls2_region_to_sf2_voice_cache, DLS2RegionToSF2VoiceCache);
-CONVERTER_SF2_VOICE_CACHE_GET_TYPE(dls2_sample_to_sf2_voice_cache, DLS2SampleToSF2VoiceCache);
+CONVERTER_SF2_VOICE_CACHE_GET_TYPE(dls2_inst_to_sf2_voice_cache, DLS2InstToSF2VoiceCache)
+CONVERTER_SF2_VOICE_CACHE_GET_TYPE(dls2_region_to_sf2_voice_cache, DLS2RegionToSF2VoiceCache)
+CONVERTER_SF2_VOICE_CACHE_GET_TYPE(dls2_sample_to_sf2_voice_cache, DLS2SampleToSF2VoiceCache)
