@@ -455,14 +455,14 @@ _sf2_sample_to_sf2_voice_cache_convert(IpatchConverter *converter,
     return (TRUE);
 }
 
-CONVERTER_CLASS_INIT(sf2_preset_to_sf2_voice_cache);
-CONVERTER_CLASS_INIT(sf2_pzone_to_sf2_voice_cache);
-CONVERTER_CLASS_INIT(sf2_inst_to_sf2_voice_cache);
-CONVERTER_CLASS_INIT(sf2_izone_to_sf2_voice_cache);
-CONVERTER_CLASS_INIT(sf2_sample_to_sf2_voice_cache);
+CONVERTER_CLASS_INIT(sf2_preset_to_sf2_voice_cache)
+CONVERTER_CLASS_INIT(sf2_pzone_to_sf2_voice_cache)
+CONVERTER_CLASS_INIT(sf2_inst_to_sf2_voice_cache)
+CONVERTER_CLASS_INIT(sf2_izone_to_sf2_voice_cache)
+CONVERTER_CLASS_INIT(sf2_sample_to_sf2_voice_cache)
 
-CONVERTER_SF2_VOICE_CACHE_GET_TYPE(sf2_preset_to_sf2_voice_cache, SF2PresetToSF2VoiceCache);
-CONVERTER_SF2_VOICE_CACHE_GET_TYPE(sf2_pzone_to_sf2_voice_cache, SF2PZoneToSF2VoiceCache);
-CONVERTER_SF2_VOICE_CACHE_GET_TYPE(sf2_inst_to_sf2_voice_cache, SF2InstToSF2VoiceCache);
-CONVERTER_SF2_VOICE_CACHE_GET_TYPE(sf2_izone_to_sf2_voice_cache, SF2IZoneToSF2VoiceCache);
-CONVERTER_SF2_VOICE_CACHE_GET_TYPE(sf2_sample_to_sf2_voice_cache, SF2SampleToSF2VoiceCache);
+CONVERTER_SF2_VOICE_CACHE_GET_TYPE(sf2_preset_to_sf2_voice_cache, SF2PresetToSF2VoiceCache)
+CONVERTER_SF2_VOICE_CACHE_GET_TYPE(sf2_pzone_to_sf2_voice_cache, SF2PZoneToSF2VoiceCache)
+CONVERTER_SF2_VOICE_CACHE_GET_TYPE(sf2_inst_to_sf2_voice_cache, SF2InstToSF2VoiceCache)
+CONVERTER_SF2_VOICE_CACHE_GET_TYPE(sf2_izone_to_sf2_voice_cache, SF2IZoneToSF2VoiceCache)
+CONVERTER_SF2_VOICE_CACHE_GET_TYPE(sf2_sample_to_sf2_voice_cache, SF2SampleToSF2VoiceCache)
