@@ -32,7 +32,6 @@
 #include <stdarg.h>
 #include <string.h>
 #include <errno.h>
-#include <locale.h>
 
 /* for mkdir */
 #include <sys/stat.h>
@@ -60,6 +59,36 @@ void _ipatch_sf2_voice_cache_init_SF2(void);
 void _ipatch_sf2_voice_cache_init_SLI(void);
 void _ipatch_sf2_voice_cache_init_gig(void);
 void _ipatch_sf2_voice_cache_init_VBank(void);
+void _ipatch_container_notify_init(void);
+void _ipatch_DLS2_infos_init(void);
+void _ipatch_DLS2_sample_init(void);
+void _ipatch_file_init(void);
+void _ipatch_item_init(void);
+void _ipatch_sample_data_init(void);
+void _ipatch_sample_store_swap_recover_init(void);
+void _ipatch_converter_init(void);
+void _ipatch_sample_transform_init();
+void _ipatch_sf2_mod_list_init();
+void _ipatch_paste_init(void);
+
+/* private free functions in other source files */
+void _ipatch_param_deinit(void);
+void _ipatch_type_prop_deinit(void);
+void _ipatch_unit_deinit(void);
+void _ipatch_xml_object_deinit(void);
+void _ipatch_util_deinit(void);
+void _ipatch_sf2_gen_deinit(void);
+void _ipatch_container_notify_deinit(void);
+void _ipatch_DLS2_infos_deinit(void);
+void _ipatch_DLS2_sample_deinit(void);
+void _ipatch_file_deinit(void);
+void _ipatch_item_deinit(void);
+void _ipatch_sample_data_deinit(void);
+void _ipatch_sample_store_swap_recover_deinit(void);
+void _ipatch_converter_deinit(void);
+void _ipatch_sample_transform_deinit(void);
+void _ipatch_sf2_mod_list_deinit(void);
+void _ipatch_paste_deinit(void);
 
 static gboolean ipatch_strv_xml_encode(GNode *node, GObject *object,
                                        GParamSpec *pspec, GValue *value,
@@ -121,6 +150,25 @@ static TypePropInit type_props[] =
 /* name of application using libInstPatch (for saving to files) */
 char *ipatch_application_name = NULL;
 
+G_LOCK_DEFINE_STATIC(lock_init);
+static int init_counter = 0;
+
+/*-----------------------------------------------------------------------------
+ Initialization / deinitialization of libinstpatch library.
+ Any application should call ipatch_init() once before any other libinstpatch
+ functions.
+ When the application is complete it must call ipatch_close().
+
+ For multi task application it is best that only one task be responsible of
+ initialization/closing. Typically, the main task of the application should
+ call ipatch_init() before creating other tasks, then when the application is
+ complete, the main task should call ipatch_close() after the other tasks are
+ completed.
+
+ If the application make use of multiple libraries each dependent of libinstpatch,
+ for each call to ipatch_init() these libraries should call ipatch_close().
+-----------------------------------------------------------------------------*/
+
 /**
  * ipatch_init:
  *
@@ -130,18 +178,20 @@ char *ipatch_application_name = NULL;
 void
 ipatch_init(void)
 {
-    static gboolean initialized = FALSE;
     TypePropInit *prop_info;
     GType type;
     int i;
 
-    if(initialized)
+    /* do nothing if the library is already initialized */
+    G_LOCK(lock_init);
+    init_counter++;
+    if(init_counter > 1)
     {
+        /* library already initialized */
+        G_UNLOCK(lock_init);
         return;
     }
 
-    initialized = TRUE;
-
     g_type_init();
 
     if(!g_thread_supported())
@@ -149,34 +199,53 @@ ipatch_init(void)
         g_thread_init(NULL);
     }
 
-    /* set up current locale.
-
-       Warning: This ensures that when loading preferences, decimal floating values are
-       properly decoded according to the LC_NUMERIC separator.
-
-       When using ipatch_xml_xxxx_decode_xxxx_func(),this will ensure that when decoding
-     float numbers, decimal part values are properly decoded. Otherwise there is risk
-     that decimal part will be ignored, leading in previous float preferences being
-     read as integer value.
-    */
-    if(!setlocale(LC_ALL, ""))
-    {
-        g_critical("Error setting locale");
-    }
-
     /* bind the gettext domain */
 #if defined(ENABLE_NLS)
     bindtextdomain(PACKAGE, LOCALEDIR);
 #endif
 
     /* Must be done before other types since they may be dependent */
+
+    /* Initialize 'GParamSpec extended properties' system */
     _ipatch_param_init();
+
+    /* Initialize the 'GObject style properties' system for GTypes */
     _ipatch_type_prop_init();
+
+    /* Initialize 'unit conversion' system */
     _ipatch_unit_init();
+
+    /* Initialize object's properties 'encoding/decoding XML handlers' system */
     _ipatch_xml_object_init();
+
+    /* Initialize GValue constant values */
     _ipatch_util_init();
+
+    /* Initialize 'SoundFont generators' subsystem */
     _ipatch_sf2_gen_init();
 
+    /*------------------------------------------------------------------------
+     Initialize object subsystem (list, hash) before objects type.
+     These list or hash are specfific to the respective object.
+     Initialization/free functions are in the respective object module file
+     Here initialization function _xxx_init() are called.
+     Respective function _xxx_deinit() are called in ipatch_deinit().
+    -------------------------------------------------------------------------*/
+    _ipatch_container_notify_init();
+    _ipatch_DLS2_infos_init();
+    _ipatch_DLS2_sample_init();
+    _ipatch_file_init();
+    _ipatch_item_init();
+    _ipatch_sample_data_init();
+    _ipatch_sample_store_swap_recover_init();
+    _ipatch_converter_init();
+    _ipatch_sample_transform_init();
+    _ipatch_sf2_mod_list_init();
+    _ipatch_paste_init();
+
+    /*-------------------------------------------------------------------------
+     initialize interfaces type before objects
+    --------------------------------------------------------------------------*/
     /* initialize interfaces before objects */
     ipatch_sample_get_type();
     ipatch_sf2_gen_item_get_type();
@@ -408,20 +477,119 @@ ipatch_init(void)
                     "mime-type", "audio/x-gigasampler", NULL);
     ipatch_type_set(IPATCH_TYPE_SLI_FILE,
                     "mime-type", "audio/x-spectralis", NULL);
+
+    G_UNLOCK(lock_init);
+}
+
+/**
+ * ipatch_deinit:
+ *
+ * Free libInstPatch library. Should be called when the application have
+ * finished.
+ */
+static void
+ipatch_deinit(void)
+{
+    g_free(ipatch_application_name);
+
+    /*-------------------------------------------------------------------------
+      Free internal systems
+    -------------------------------------------------------------------------*/
+    /* Free 'GParamSpec extended properties' system */
+    _ipatch_param_deinit();
+
+    /* Free the 'GObject style properties' system for GTypes */
+    _ipatch_type_prop_deinit();
+
+    /* Free 'unit conversion' system */
+    _ipatch_unit_deinit();
+
+    /* Free object's properties 'encoding/decoding XML handlers' system */
+    _ipatch_xml_object_deinit();
+
+    /* Free GValue constant values */
+    _ipatch_util_deinit();
+
+    /* Free 'SoundFont generators' subsystem */
+    _ipatch_sf2_gen_deinit();
+
+    /*-------------------------------------------------------------------------
+     Free object subsystem (list, hash).
+     These list or hash are specfific to the respective object.
+     Initialization/deinitialization functions are in the respective object
+     module file.
+     Here deinitialization functions  _xxx_deinit() are called.
+     Respective initialization functions _xxx_init() are called in
+     ipatch_init().
+    -------------------------------------------------------------------------*/
+    /* Free container subsystem */
+    _ipatch_container_notify_deinit();
+
+    /* Free DLS2 subsystem */
+    _ipatch_DLS2_infos_deinit();
+
+    /* Free DLS2 sample subsystem */
+    _ipatch_DLS2_sample_deinit();
+
+    /* Free File subsystem */
+    _ipatch_file_deinit();
+
+    /* Free Item propterty subsystem */
+    _ipatch_item_deinit();
+
+    /* Free Sample data subsystem */
+    _ipatch_sample_data_deinit();
+
+    /* Free Sample store swap recovery subsystem */
+    _ipatch_sample_store_swap_recover_deinit();
+
+    /* Free converter subsytem */
+    _ipatch_converter_deinit();
+
+    /* Free Audio format conversion subsystem */
+    _ipatch_sample_transform_deinit();
+
+    /* Free default mod list */
+    _ipatch_sf2_mod_list_deinit();
+
+    /* Free paste handlers list */
+    _ipatch_paste_deinit();
 }
 
 /**
  * ipatch_close:
  *
- * Perform cleanup of libInstPatch prior to application close.  Such as deleting
- * temporary files.
+ * This should be called prior to application close.
  *
+ * Decrement the reference counter and if it reaches 0 performs cleanup of
+ * libInstPatch, such as deleting temporary files and internal caches.
+ * If the counter is still > 0, the function return without doing cleanup
+ * (the library is still owned).
+ *
+ * Does nothing if the library is already deinitialized (or was not initialized).
  * Since: 1.1.0
  */
 void
 ipatch_close(void)
 {
+    /* do nothing if the library is already deinitialized */
+    G_LOCK(lock_init);
+    init_counter--;
+    if(init_counter != 0)
+    {
+        /* library still owned by a task, do nothing */
+        if(init_counter < 0)
+        {
+            init_counter = 0;
+        }
+        G_UNLOCK(lock_init);
+        return;
+    }
+
     ipatch_sample_store_swap_close();
+    ipatch_deinit();
+
+    G_UNLOCK(lock_init);
 }
 
 static gboolean
